@@ -1,12 +1,20 @@
 use strict;
 package Web::Authenticate::Authenticator::Role;
-$Web::Authenticate::Authenticator::Role::VERSION = '0.006';
+$Web::Authenticate::Authenticator::Role::VERSION = '0.007';
 use Mouse::Role;
 #ABSTRACT: A Mouse::Role that defines what methods a Web::Authenticate::Authenticator object should contain.
 
 
 requires 'authenticate';
 
+
+requires 'name';
+
+
+requires 'error_msg';
+
+
+
 1;
 
 __END__
@@ -21,7 +29,7 @@ Web::Authenticate::Authenticator::Role - A Mouse::Role that defines what methods
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 METHODS
 
@@ -31,6 +39,14 @@ Authenticates a user based on some criteria. Returns true (1) or false (undef).
 
     my $authenticated = $authenticator->authenticate($user);
 
+=head2 name
+
+Returns the name of this authenticator.
+
+=head2 error_msg
+
+Returns the error message if this authenticator fails.
+
 =head1 AUTHOR
 
 Adam Hopkins <srchulo@cpan.org>
