@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Session::Storage::Handler::SQL;
-$Web::Authenticate::Session::Storage::Handler::SQL::VERSION = '0.006';
+$Web::Authenticate::Session::Storage::Handler::SQL::VERSION = '0.007';
 use Mouse;
 use Carp;
 use DateTime;
@@ -116,14 +116,6 @@ has expires_field => (
 );
 
 
-has allow_multiple_session_per_user => (
-    isa => 'Bool',
-    is => 'ro',
-    required => 1,
-    default => undef,
-);
-
-
 has dbix_raw => (
     isa => 'DBIx::Raw',
     is => 'ro',
@@ -262,7 +254,6 @@ sub delete_session {
 sub invalidate_user_sessions {
     my ($self, $user) = @_;
     croak "must provide user" unless $user;
-    return if $self->allow_multiple_session_per_user;
 
     my $sessions_table = $self->sessions_table;
     my $user_id_field = $self->user_id_field;
@@ -309,7 +300,7 @@ Web::Authenticate::Session::Storage::Handler::SQL - Implementation of Web::Authe
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
@@ -325,7 +316,7 @@ This L<Web::Authenticate::Session::Storage::Handler::Role> is meant to be used w
 Other columns can exists, and the names of the table and column can change. But at least these columns must exist
 in order for this storage handler to work properly. Also, the primary key does not have to be an integer, and could
 even be the session_id. Also, the user_id does not need to be unique if you want to allow multiple sessions for a
-user by setting L</allow_multiple_session_per_user> to true.
+user by setting L<Web::Authenticate/allow_multiple_sessions_per_user> to true.
 
 =head1 METHODS
 
@@ -401,11 +392,6 @@ Sets the name of the ip address field if L</require_same_ip_address> is set to 1
 
 Sets the name of the expires time field that will be used when querying the database. Default is 'expires'.
 
-=head2 allow_multiple_session_per_user
-
-A bool (1 or undef) whether or not to allow multiple sessions per user. If set to true, when L</invalidate_user_sessions> is
-called nothing will happen. Default is false.
-
 =head2 dbix_raw
 
 Sets the L<DBIx::Raw> object that will be used to query the database. This is required with no default.
@@ -453,7 +439,7 @@ Deletes a session from storage.
 
 =head2 invalidate_user_sessions
 
-Invalidates (deletes) any user sessions for user unless L</allow_multiple_session_per_user> is set to true.
+Invalidates (deletes) any user sessions for user.
 
     $session_storage_handler->invalidate_user_sessions($user);
 
